OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "內嵌郵件 %s",
    "Important mail" : "重要郵件",
    "Unread mail" : "未讀郵件",
    "Important" : "重要",
    "Work" : "工作",
    "Personal" : "個人",
    "To Do" : "待辦",
    "Later" : "稍後",
    "Mails" : "郵件",
    "Mail" : "電子郵件",
    "💌 A mail app for Nextcloud" : "Nextcloud 的郵件應用程式",
    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](https://horde.org) libraries.\n- **📬 Want to host your own mail server?** We do not have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 的郵件應用程式**\n\n- **🚀 與其他 Nextcloud 應用程式整合！** 目前有聯絡人、日曆與檔案 – 還會有更多。\n- **📥 多組郵件帳號！** 私人與公司帳號？沒問題，而且有很好的統一收件匣。可連線到任何 IMAP 帳號。\n- **🔒 傳送與接收加密電子郵件！** 使用超棒的 [Mailvelope](https://mailvelope.com) 瀏覽器擴充套件。\n- **🙈 我們並未重新發明輪子！** 以超棒的 [Horde](https://horde.org) 函式庫為基礎。\n- **📬 想要自架郵件伺服器嗎？** 我們不用重新實作此動作，因為您可以設定 [Mail-in-a-Box](https://mailinabox.email)！",
    "Your session has expired. The page will be reloaded." : "您的工作階段已過期。頁面將會重新載入。",
    "Drafts are saved in:" : "草稿儲存於：",
    "Sent messages are saved in:" : "已傳送的郵件儲存於：",
    "Deleted messages are moved in:" : "已刪除的郵件移動至：",
    "Archived messages are moved in:" : "封存的訊息被移動至：",
    "Auto" : "自動",
    "Name" : "名字",
    "Mail address" : "電子郵件地址",
    "name@example.org" : "name@example.org",
    "Please enter an email of the format name@example.com" : "請輸入格式為 name@example.com 的電子郵件地址",
    "Password" : "密碼",
    "Manual" : "手動",
    "IMAP Settings" : "IMAP 設定",
    "IMAP Host" : "IMAP 主機",
    "IMAP Security" : "IMAP 安全性",
    "None" : "無",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 連接埠",
    "IMAP User" : "IMAP 帳號",
    "IMAP Password" : "IMAP 密碼",
    "SMTP Settings" : "SMTP 設定",
    "SMTP Host" : "SMTP 主機",
    "SMTP Security" : "SMTP 安全性",
    "SMTP Port" : "SMTP 連接埠",
    "SMTP User" : "SMTP 帳號",
    "SMTP Password" : "SMTP 密碼",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "要讓 Google 帳號與此應用程式搭配使用，您必須為 Google 帳號啟用雙重驗證並產生應用程式密碼。",
    "Connecting" : "正在連線",
    "Reconnect Google account" : "重新連結 Google 帳號",
    "Sign in with Google" : "使用 Google 登入",
    "Save" : "儲存",
    "Connect" : "連線",
    "Looking up configuration" : "正在查詢設定",
    "Checking mail host connectivity" : "正在檢查郵件主機連線能力",
    "Configuration discovery failed. Please use the manual settings" : "設定探索失敗。請使用手動設定",
    "Password required" : "請輸入密碼",
    "Testing authentication" : "正在測試驗證",
    "Awaiting user consent" : "等待使用者同意",
    "Account created. Please follow the popup instructions to link your Google account" : "帳號已建立。請按照彈出的說明連結您的 Google 帳號",
    "Loading account" : "正在載入帳號",
    "Account updated. Please follow the popup instructions to reconnect your Google account" : "帳號已更新。請按照彈出的說明重新連結您的 Google 帳號",
    "Account updated" : "已更新帳號",
    "IMAP server is not reachable" : "IMAP 伺服器無法連線",
    "SMTP server is not reachable" : "SMTP 伺服器無法連線",
    "IMAP username or password is wrong" : "IMAP 使用者名稱或密碼錯誤",
    "SMTP username or password is wrong" : "SMTP 使用者名稱或密碼錯誤",
    "IMAP connection failed" : "IMAP 連線失敗",
    "SMTP connection failed" : "SMTP 連線失敗",
    "Authorization pop-up closed" : "已關閉授權彈出式視窗",
    "There was an error while setting up your account" : "設定您的帳號時發生錯誤",
    "Account settings" : "帳號設定",
    "Alias to S/MIME certificate mapping" : "別名至 S/MIME 憑證對映",
    "Signature" : "簽章",
    "A signature is added to the text of new messages and replies." : "對新信件與回覆信件內容已新增一個簽名檔",
    "Writing mode" : "寫作模式",
    "Preferred writing mode for new messages and replies." : "新郵件與回覆偏好的寫作模式。",
    "Default folders" : "預設資料夾",
    "The folders to use for drafts, sent messages, deleted messages and archived messages." : "用於草稿、寄件備份、已刪除訊息與封存的訊息的資料夾。",
    "Autoresponder" : "自動回覆程式",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "自動回覆收到的訊息。若某人向您傳送多則訊息，此自動回覆將會最多每四天傳送一次。",
    "Please connect to a sieve server first." : "請先連結至 sieve 伺服器。",
    "Sieve filter rules" : "過濾規則",
    "Trusted senders" : "信任的寄件者",
    "Mail server" : "郵件伺服器",
    "Sieve filter server" : "過濾伺服器",
    "Update alias" : "更新别名",
    "Rename alias" : "重新命名別名",
    "Show update alias form" : "顯示更新別名表格",
    "Delete alias" : "删除别名",
    "Go back" : "返回",
    "Change name" : "更改名稱",
    "Email address" : "電子郵件地址",
    "Add alias" : "新增別名",
    "Create alias" : "建立別名",
    "Cancel" : "取消",
    "Add mail account" : "新增郵件帳號",
    "Use Gravatar and favicon avatars" : "使用個人化大頭貼與網站圖示",
    "Register as application for mail links" : "註冊為郵件連結的處理應用程式",
    "Show keyboard shortcuts" : "顯示鍵盤快捷鍵",
    "Manage S/MIME certificates" : "管理 S/MIME 憑證",
    "Looking for a way to encrypt your emails?" : "正在尋找加密您的電子郵件的方法？",
    "Install Mailvelope browser extension here" : "在此安裝 Mailvelope 瀏覽器擴充套件",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "允許應用程式蒐集關於您互動的資料。以此資料為基礎，應用程式將會適應您的偏好設定。資料將只會儲存在本機。",
    "Put my text to the bottom of a reply instead of on top of it." : "將我的文字放在回覆的底部而非頂部。",
    "Automatically classify importance of new email" : "自動分類新電子郵件的重要性",
    "Could not update preference" : "無法更新偏好設定",
    "Select an alias" : "選取別名",
    "Update Certificate" : "更新憑證",
    "No certificate" : "無憑證",
    "Certificate updated" : "憑證已更新",
    "Could not update certificate" : "無法更新憑證",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - 有效期限至 {expiryDate}",
    "From" : "從",
    "Select account" : "選取帳號",
    "To" : "至",
    "Contact or email address …" : "聯絡人或電子郵件地址……",
    "Toggle recipients list mode" : "切換收件人清單模式",
    "Cc" : "副本",
    "Bcc" : "密件副本",
    "No contacts found." : "找不到聯絡人。",
    "Subject" : "主旨",
    "Subject …" : "主旨……",
    "This message came from a noreply address so your reply will probably not be read." : "此郵件來自 noreply 地址，所以您的回覆可能不會被閱讀。",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "以下收件者沒有 S/MIME 憑證：{recipients}。",
    "The following recipients do not have a PGP key: {recipients}." : "以下收件者沒有 PGP 金鑰：{recipients}。",
    "Write message …" : "編寫郵件……",
    "Saving draft …" : "正在儲存草稿……",
    "Error saving draft" : "儲存草稿時發生錯誤",
    "Draft saved" : "草稿已儲存",
    "Save draft" : "儲存草稿",
    "Discard & close draft" : "放棄並關閉草稿",
    "Upload attachment" : "已上傳附件",
    "Add attachment from Files" : "從雲端檔案中加入附件",
    "Smart picker" : "智慧型挑選器",
    "Send later" : "稍後傳送",
    "Enable formatting" : "啟用格式",
    "Disable formatting" : "停用格式化",
    "Request a read receipt" : "索取讀取回條",
    "Sign message with S/MIME" : "使用 S/MIME 簽署訊息",
    "Encrypt message with S/MIME" : "使用 S/MIME 加密訊息",
    "Encrypt message with Mailvelope" : "使用 Mailvelope 加密郵件",
    "Send now" : "立刻傳送",
    "Tomorrow morning" : "明天早上",
    "Tomorrow afternoon" : "明天下午",
    "Monday morning" : "週一早上",
    "Custom date and time" : "自訂日期與時間",
    "Enter a date" : "輸入日期",
    "Add share link from {productName} Files" : "從 {productName} 檔案新增分享連結",
    "Encrypt with S/MIME and send later" : "使用 S/MIME 加密並稍後傳送",
    "Encrypt with S/MIME and send" : "使用 S/MIME 加密並傳送",
    "Encrypt with Mailvelope and send later" : "使用 Mailvelope 加密並稍後傳送",
    "Encrypt with Mailvelope and send" : "使用 Mailvelope 加密並傳送",
    "Send" : "傳送",
    "Message {id} could not be found" : "找不到郵件 {id}",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "已選取使用 S/MIME 簽署或加密，但選定的別名沒有憑證。此訊息將不會被簽署或加密。",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "任何現有格式（例如粗體、義式斜體、底線或內嵌圖片）都將被移除。",
    "Turn off formatting" : "關閉格式化",
    "Turn off and remove formatting" : "關閉並移除格式化",
    "Keep formatting" : "保留格式化",
    "Choose a file to add as attachment" : "選擇要作為附件的檔案",
    "Choose a file to share as a link" : "選擇要作為連結分享的檔案",
    "_{count} attachment_::_{count} attachments_" : ["{count} 個附件"],
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["附件超過了允許的附件大小 {size}。請透過連結分享檔案。"],
    "Untitled message" : "未命名訊息",
    "Confirm" : "確認",
    "No message found yet" : "找不到訊息",
    "Set up an account" : "設定帳號",
    "Plain text" : "純文字",
    "Rich text" : "RTF",
    "No messages in this mailbox" : "此信箱中沒有郵件",
    "No messages" : "沒有郵件",
    "Draft: " : "草稿：",
    "Encrypted message" : "加密訊息",
    "This message is unread" : "此訊息未讀",
    "Unfavorite" : "取消收藏",
    "Favorite" : "收藏",
    "Unread" : "未讀",
    "Read" : "已讀",
    "Unimportant" : "不重要",
    "Mark not spam" : "標記為非垃圾郵件",
    "Mark as spam" : "標記為垃圾郵件",
    "Unselect" : "取消選取",
    "Select" : "選取",
    "Edit tags" : "編輯標籤",
    "Move thread" : "移動討論串",
    "Archive thread" : "封存討論串",
    "Delete thread" : "刪除討論串",
    "More actions" : "更多動作",
    "Edit as new message" : "以新郵件的方式編輯",
    "Create event" : "建立事件",
    "Create task" : "建立工作項目",
    "Download message" : "下載訊息",
    "Blind copy recipients only" : "僅密件副本收件者",
    "No subject" : "沒有主旨",
    "No trash mailbox configured" : "未設定垃圾信箱",
    "Could not delete message" : "無法刪除郵件",
    "Could not archive message" : "無法封存訊息",
    "Forward" : "轉寄",
    "Load more" : "載入更多",
    "_Mark {number} unread_::_Mark {number} unread_" : ["將 {number} 標記為未讀"],
    "_Mark {number} read_::_Mark {number} read_" : ["將 {number} 標記為已讀"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["將 {number} 標記為重要"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["將 {number} 標記為不重要"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["取消我的最愛 {number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["我的最愛 {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["取消選取 {number}"],
    "_Move {number} thread_::_Move {number} threads_" : ["移動 {number} 個討論串"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["轉寄 {number} 作為附件"],
    "_Delete {number} thread_::_Delete {number} threads_" : ["刪除 {number} 個討論串"],
    "Report this bug" : "回報此臭蟲",
    "All day" : "全天",
    "Create" : "建立",
    "Event created" : "已建立事件",
    "Could not create event" : "無法建立活動",
    "You accepted this invitation" : "您接受了此邀请",
    "You tentatively accepted this invitation" : "您暫時接受了此邀請",
    "You declined this invitation" : "您拒絕了此邀請",
    "You already reacted to this invitation" : "您已對此邀請作出回應",
    "You have been invited to an event" : "您已受邀參加活動",
    "This event was cancelled" : "此活動已取消",
    "Save to" : "儲存為",
    "Comment" : "留言",
    "Accept" : "接受",
    "Decline" : "回絕",
    "Tentatively accept" : "暫時接受",
    "More options" : "更多選項",
    "This event is in the past." : "此活動發生於過去。",
    "This event was updated" : "此活動已更新",
    "{attendeeName} accepted your invitation" : "{attendeeName} 已接受您的邀請",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} 暫時接受了您的邀請",
    "{attendeeName} declined your invitation" : "{attendeeName} 已拒絕您的邀請",
    "{attendeeName} reacted to your invitation" : "{attendeeName} 已對您的邀請作出回應",
    "Failed to save your participation status" : "儲存您的參與狀態失敗",
    "Could not open mailbox" : "無法開啟信箱",
    "Loading messages …" : "正在載入郵件……",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "正在索引您的郵件。對於較大的信箱來說，這可能需要較長的時間。",
    "To archive a message please configure an archive mailbox in account settings" : "要封存訊息，請在帳號設定中設定封存信箱。",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "您不能將此訊息移到封存資料夾及/或從目前資料夾中刪除此訊息",
    "Choose target mailbox" : "選擇目標信箱",
    "No more submailboxes in here" : "這裡沒有更多子信箱",
    "Choose" : "選擇",
    "Important info" : "重要資訊",
    "Other" : "其他",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "郵件將會以您與其互動或標記為重要的郵件為基礎來自動標記重要郵件。ㄧ開始，您可以能必須手動教導系統哪些是重要郵件，然後它就會與時俱進。",
    "The sender of this message has asked to be notified when you read this message." : "當您閱讀此郵件時，此郵件的寄件者要求通知。",
    "Notify the sender" : "通知寄件者",
    "You sent a read confirmation to the sender of this message." : "你已將讀取回條傳送給此郵件的寄件者。",
    "Could not send mdn" : "無法傳送 mdn",
    "Reply all" : "回覆所有人",
    "Reply" : "回覆",
    "Reply to sender only" : "僅回覆寄件者",
    "Move message" : "移動訊息",
    "Forward message as attachment" : "將郵件作為附件轉發",
    "View source" : "檢視原始碼",
    "Download thread data for debugging" : "下載郵件串的資料以供除錯",
    "Message source" : "郵件原始碼",
    "Message body" : "郵件正文",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "警告：此郵件的 S/MIME 簽章未經驗證。寄件人可能在冒充某人！",
    "Import into calendar" : "匯入到日曆",
    "Download attachment" : "下載附件",
    "Save to Files" : "儲存至雲端檔案",
    "Unnamed" : "未命名",
    "Embedded message" : "內嵌郵件",
    "Choose a folder to store the attachment in" : "選擇一個資料夾來存放附件",
    "View fewer attachments" : "檢視較少附件",
    "Save all to Files" : "全部儲存至檔案",
    "Download Zip" : "下載 Zip 壓縮檔",
    "Choose a folder to store the attachments in" : "選擇一個資料夾來存放附件",
    "_View {count} more attachment_::_View {count} more attachments_" : ["檢視另外 {count} 個附件"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "此郵件使用 PGP 加密。安裝 Mailvelope 來解密。",
    "The images have been blocked to protect your privacy." : "為維護您的隱私，圖片將不會被載入。",
    "Show images" : "顯示圖片",
    "Show images temporarily" : "暫時顯示圖片",
    "Always show images from {sender}" : "一律顯示來自 {sender} 的圖片",
    "Always show images from {domain}" : "一律顯示來自 {domain} 的圖片",
    "Message frame" : "郵件框",
    "Quoted text" : "引用文字",
    "Move" : "移動",
    "Moving" : "正在移動",
    "Moving thread" : "正在移動討論串",
    "Moving message" : "正在移動訊息",
    "Mail settings" : "電子郵件設定",
    "Provisioned account is disabled" : "預先設定的帳號已停用",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "請使用密碼登入以啟用此帳號。目前的工作階段正在使用無密碼身份驗證，例如 SSO 或 WebAuthn。",
    "Quota" : "用量",
    "Show only subscribed mailboxes" : "僅顯示已訂閱的信箱",
    "Add mailbox" : "新增信箱",
    "Saving" : "正在儲存",
    "Move up" : "向上移動",
    "Move down" : "向下移動",
    "Remove account" : "移除帳號",
    "Loading …" : "正在載入……",
    "Not supported by the server" : "不被伺服器支援",
    "{usage} of {limit} used" : "已使用 {limit} 中的 {usage}",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email} 帳號與已快取的電子郵件將會從 Nextcloud 移除，但不會從您的電子郵件提供商移除。",
    "Remove account {email}" : "移除帳號 {email}",
    "Remove {email}" : "移除 {email}",
    "Show all subscribed mailboxes" : "顯示所有已訂閱的信箱",
    "Show all mailboxes" : "顯示所有信箱",
    "Collapse mailboxes" : "折疊信箱",
    "Mark all as read" : "全部標記為已讀",
    "Mark all messages of this mailbox as read" : "將此信箱所有的郵件標記為已讀",
    "Add submailbox" : "新增子信箱",
    "Edit name" : "編輯名稱",
    "Move mailbox" : "移動信箱",
    "Clear cache" : "清除快取",
    "Clear locally cached data, in case there are issues with synchronization." : "如果遇到同步問題，請清除本機快取資料。",
    "Subscribed" : "已訂閱",
    "Sync in background" : "背景同步",
    "Clear mailbox" : "清除信箱",
    "Delete mailbox" : "刪除信箱",
    "All messages in mailbox will be deleted." : "郵箱中的所有訊息都將被刪除。",
    "Clear mailbox {name}" : "清除信箱 {name}",
    "The mailbox and all messages in it will be deleted." : "信箱與其中的所有郵件都會被刪除。",
    "Delete mailbox {name}" : "刪除信箱 {name}",
    "An error occurred, unable to rename the mailbox." : "遇到錯誤，無法重新命名信箱。",
    "_{total} message_::_{total} messages_" : ["{total} 封郵件"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{total} 中的 {unread} 未讀"],
    "Outbox" : "寄件匣",
    "New message" : "新郵件",
    "Refresh" : "重新整理",
    "Error sending your message" : "傳送您的郵件時發生錯誤",
    "Retry" : "重試",
    "Uploading attachments …" : "正在上傳附件……",
    "Sending …" : "正在傳送……",
    "Warning sending your message" : "在傳送您的郵件時警告",
    "Send anyway" : "無論無何都要傳送",
    "Edit message" : "編輯訊息",
    "Draft" : "草稿",
    "Message saved" : "訊息已儲存",
    "Failed to save message" : "儲存訊息失敗",
    "Failed to save draft" : "儲存草稿失敗",
    "No sent mailbox configured. Please pick one in the account settings." : "未設定寄件備份信箱。請在帳號設定中選取。",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "您正試圖傳送郵件給「收件者」及／或「副本」中的許多人。請考慮使用「密件副本」來隱藏收件者地址。",
    "Message discarded" : "郵件已捨棄",
    "Could not discard message" : "無法捨棄郵件",
    "No message selected" : "未選取郵件",
    "Autoresponder off" : "自動回覆程式停用",
    "Autoresponder on" : "自動回覆程式啟用",
    "First day" : "第一天",
    "Last day (optional)" : "最後一天（選擇性）",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} 將替換為您要回應的郵件的主旨",
    "Message" : "訊息",
    "Oh Snap!" : "喔喔！",
    "Save autoresponder" : "儲存自動回覆程式",
    "Could not open outbox" : "無法開啟寄件匣",
    "Pending or not sent messages will show up here" : "待處理或未傳送的郵件將會在此處顯示",
    "Delete" : "刪除",
    "Message could not be sent" : "無法傳送郵件",
    "Message deleted" : "郵件已刪除",
    "Contacts with this address" : "有此地址的聯絡人",
    "Add to Contact" : "新增至聯絡人",
    "New Contact" : "新聯絡人",
    "Copy to clipboard" : "複製到剪貼簿",
    "Contact name …" : "聯絡人名稱……",
    "Add" : "新增",
    "Copied email address to clipboard" : "將電子郵件地址複製到剪貼簿",
    "Could not copy email address to clipboard" : "無法複製電子郵件地址到剪貼簿",
    "Search in mailbox" : "在郵件匣中搜尋",
    "Close" : "關閉",
    "Search parameters" : "搜尋參數",
    "Search term" : "搜尋字詞",
    "Pick a start date" : "挑選開始日期",
    "Pick an end date" : "挑選結束日期",
    "Select senders" : "選取寄件者",
    "Select recipients" : "選取收件者",
    "Select CC recipients" : "選取副本收件者",
    "Select BCC recipients" : "選取密件副本收件者",
    "Tags" : "標籤",
    "Select tags" : "選取標籤",
    "Marked as" : "已標記為",
    "Has attachments" : "有附件",
    "Clear" : "清除",
    "Search" : "搜尋",
    "Date" : "日期",
    "Disabled" : "已停用",
    "Enabled" : "已啟用",
    "Sieve Host" : "過濾主機",
    "Sieve Security" : "過濾安全",
    "Sieve Port" : "過濾連接埠",
    "Sieve Credentials" : "過濾憑證",
    "IMAP Credentials" : "IMAP 憑證",
    "Custom" : "自訂",
    "Sieve User" : "過濾使用者",
    "Sieve Password" : "過濾密碼",
    "Save sieve settings" : "儲存過濾設定",
    "Save sieve script" : "儲存過濾指令稿",
    "The syntax seems to be incorrect:" : "語法似乎不正確：",
    "Signature …" : "簽名……",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "您的簽名檔大於 2 MB。這可能會影響編輯器的效能。",
    "Save signature" : "儲存簽名",
    "Place signature above quoted text" : "將簽名置於引用文字上方",
    "Add default tags" : "新增預設標籤",
    "Rename tag" : "重新命名標籤",
    "Saving new tag name …" : "正在儲存新的標籤名稱……",
    "Set tag" : "設定標籤",
    "Unset tag" : "取消設定標籤",
    "Add tag" : "新增標籤",
    "Saving tag …" : "正在儲存標籤……",
    "Tag name is a hidden system tag" : "標籤名稱為隱藏的系統標籤",
    "Tag already exists" : "標籤已經存在",
    "An error occurred, unable to create the tag." : "遇到錯誤，無法建立標籤。",
    "An error occurred, unable to rename the tag." : "發生錯誤，無法重新命名標籤。",
    "Select calendar" : "選取日曆",
    "No calendars with task list support" : "沒有支援工作清單的日曆",
    "Task created" : "已建立工作",
    "Could not create task" : "無法建立工作",
    "Loading thread" : "正在載入討論串",
    "Not found" : "找不到",
    "Could not load your message thread" : "無法載入您的郵件串",
    "The thread doesn't exist or has been deleted" : "討論串不存在或已被刪除",
    "Unsubscribe" : "取消訂閱",
    "Mark as unfavorite" : "取消標記為我的最愛",
    "Mark as favorite" : "標記為我的最愛",
    "Mark as unread" : "標為未讀",
    "Mark as read" : "標為已讀",
    "Archive message" : "封存訊息",
    "Delete message" : "刪除訊息",
    "Unsubscribe via link" : "透過連結取消訂閱",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "取消訂閱將停止來自郵件清單 {sender} 的所有訊息",
    "Send unsubscribe email" : "傳送取消訂閱電子郵件",
    "Unsubscribe via email" : "透過電子郵件取消訂閱",
    "Encrypted & verified " : "加密與驗證",
    "Signature verified" : "簽章已驗證",
    "Signature unverified " : "簽章未驗證",
    "This message was encrypted by the sender before it was sent." : "此訊息在傳送前已由寄件人加密。",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "此訊息包含了已驗證的數位 S/MIME 簽章。訊息自傳送後未變更。",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "此訊息包含了未驗證的 S/MIME 簽章。訊息在傳送後可能已被變更，或是簽章者的證書不受信任。",
    "Unsubscribe request sent" : "取消訂閱請求已傳送",
    "Could not unsubscribe from mailing list" : "無法從郵件清單取消訂閱",
    "Remove" : "移除",
    "No senders are trusted at the moment." : "目前沒有寄件者受到信任。",
    "Could not remove trusted sender {sender}" : "無法移除受信任的寄件者 {sender}",
    "individual" : "個人",
    "domain" : "網域",
    "(organizer)" : "（主辦人）",
    "Untitled event" : "未命名活動",
    "Import into {calendar}" : "已匯入至 {calendar}",
    "Event imported into {calendar}" : "活動已匯入至 {calendar}",
    "Airplane" : "飛機",
    "Reservation {id}" : "預訂 {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "航班 {flightNr} 從 {depAirport} 至 {arrAirport}",
    "Train" : "火車",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} 從 {depStation} 至 {arrStation}",
    "Train from {depStation} to {arrStation}" : "從 {depStation} 至 {arrStation} 的火車",
    "Mail app" : "郵件應用程式",
    "The mail app allows users to read mails on their IMAP accounts." : "郵件應用程式允許使用者閱讀在他們 IMAP 帳號上的郵件。",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "您可以在此找到全站台的設定。在應用程式本身（左下角）可以找到使用者設定。",
    "Account provisioning" : "帳號設定",
    "A provisioning configuration will provision all accounts with a matching email address." : "預備設定將會為所有符合特定電子郵件地址的帳號提供。",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "在預備網域欄位中使用萬用字元 (*) 將會建立適用於所有使用者的設定，前提是這些使用者與其他設定不相符。",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "預備機制將優先於特定的網域設定，最後才是萬用字元網域設定。",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "如果使用者已被提供另一個設定後，又發現新的符合的設定，那麼新設定優先，使用者將會重新使用該設定。",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "每個網域只能有一個設定，且僅能有一個萬用字元網域設定。",
    "These settings can be used in conjunction with each other." : "這些設定可以相互結合使用。",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "如果您只想為所有使用者預備一個網域，請使用萬用字元 (*)。",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "此設定僅在您組織的 Nextcloud 與郵件伺服器使用相同的使用者後端時才有用。",
    "Provisioning Configurations" : "帳號設定",
    "Add new config" : "加入新設定",
    "Provision all accounts" : "預備所有帳號",
    "Allow additional mail accounts" : "允許其他郵件帳號",
    "Allow additional Mail accounts from User Settings" : "從使用者設定允許其他郵件帳號",
    "Anti Spam Service" : "反垃圾郵件服務",
    "You can set up an anti spam service email address here." : "您可以在此設定反垃圾郵件服務的電子郵件地址。",
    "Any email that is marked as spam will be sent to the anti spam service." : "任何被標記為垃圾郵件的電子郵件都將會被傳送至反垃圾郵件服務。",
    "Gmail integration" : "Gmail 整合",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail 讓使用者可以透過 IMAP 存取他們的電子郵件。出於安全理由，僅能使用 OAuth 2.0 連線或使用雙重驗證與應用程式密碼的 Google 帳號才能進行此存取。",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "您必須在 Google Cloud 主控台中的「Web 應用程式」註冊一個新的客戶端 ID。新增 URL {url} 作為授權重新導向 URI。",
    "Microsoft integration" : "Microsoft 整合",
    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft 允許使用者透過 IMAP 存取電子郵件。出於安全性的原因，此存取只能透過 OAuth 2.0 連線進行。",
    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "您必須在 Microsoft Azure Active Directory 入口網站中註冊一個新應用程式。然後新增 URL {url} 作為重新導向 URI。",
    "Successfully updated config for \"{domain}\"" : "成功為「{domain}」更新設定",
    "Error saving config" : "儲存設定時發生錯誤",
    "Saved config for \"{domain}\"" : "已為「{domain}」儲存設定",
    "Could not save provisioning setting" : "無法儲存預備設定",
    "There was an error when provisioning accounts." : "設定帳號時發生錯誤。",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "成功刪除並取消設定了「{domain}」的帳號",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "刪除並取消設定「{domain}」的帳號時發生錯誤",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["成功設定 {count} 個帳號。"],
    "Anti Spam" : "反垃圾郵件",
    "Add the email address of your anti spam report service here." : "在此新增您的反垃圾郵件回報服務電子郵件地址。",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "使用此設定時，當使用者點擊「標記為垃圾郵件」時，會向垃圾郵件回報伺服器傳送回報電子郵件。",
    "The original message will be attached as a \"message/rfc822\" attachment." : "原始訊息將會以「message/rfc822」作為附件。",
    "\"Mark as Spam\" Email Address" : "「標記為垃圾郵件」電子郵件地址",
    "\"Mark Not Junk\" Email Address" : "「標記為非垃圾郵件」電子郵件地址",
    "Reset" : "重設",
    "Successfully set up anti spam email addresses" : "成功設定了反垃圾郵件電子郵件地址",
    "Error saving anti spam email addresses" : "儲存反垃圾郵件電子郵件地址時發生錯誤",
    "Successfully deleted anti spam reporting email" : "成功刪除了反垃圾電子郵件回報電子郵件",
    "Error deleting anti spam reporting email" : "刪除反垃圾郵件回報電子郵件時發生錯誤",
    "Client ID" : "客戶端 ID",
    "Client secret" : "客戶端密碼",
    "Unlink" : "取消連結",
    "Google integration configured" : "已設定 Google 整合",
    "Could not configure Google integration" : "無法設定 Google 整合",
    "Google integration unlinked" : "Google 整合已取消連結",
    "Could not unlink Google integration" : "無法取消連結 Google 整合",
    "Tenant ID (optional)" : "租戶 ID（選擇性）",
    "Microsoft integration configured" : "已設定 Microsoft 整合",
    "Could not configure Microsoft integration" : "無法設定 Microsoft 整合",
    "Microsoft integration unlinked" : "取消連結 Microsoft 整合",
    "Could not unlink Microsoft integration" : "無法取消連結 Microsoft 整合",
    "Domain Match: {provisioningDomain}" : "網域符合：{provisioningDomain}",
    "Email: {email}" : "電子郵件：{email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP：{user} 在 {host}:{port}（{ssl} 加密）",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP：{user} 在 {host}:{port}（{ssl} 加密）",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "過濾：{user} 在 {host}:{port}（{ssl} 加密）",
    "Configuration for \"{provisioningDomain}\"" : "「{provisioningDomain}」的設定",
    "General" : "一般",
    "Provisioning domain" : "預備設定網域",
    "Email address template" : "電子郵件地址範本",
    "IMAP" : "IMAP",
    "User" : "使用者",
    "Host" : "主機",
    "Port" : "連接埠",
    "SMTP" : "SMTP",
    "Sieve" : "過濾",
    "Enable sieve integration" : "啟用過濾整合",
    "LDAP aliases integration" : "LDAP 別名整合",
    "Enable LDAP aliases integration" : "啟用 LDAP 別名整合",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAP 別名整合會從設定好的 LDAP 目錄讀取屬性以提供電子郵件別名。",
    "LDAP attribute for aliases" : "別名的 LDAP 屬性",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "用於設定電子郵件別名的多重值屬性。為每個值建立一個別名。刪除存在於 Nextcloud 但不在 LDAP 目錄中的別名。",
    "Save Config" : "儲存設定",
    "Unprovision & Delete Config" : "取消設定與刪除設定",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% 與 %EMAIL% 將以使用者的 UID 與電子郵件取代",
    "With the settings above, the app will create account settings in the following way:" : "使用上述設定，應用程式將會以下列方式建立帳號：",
    "S/MIME certificates" : "S/MIME 憑證",
    "Certificate name" : "憑證名稱",
    "E-mail address" : "電子郵件地址",
    "Valid until" : "到期日",
    "Delete certificate" : "刪除憑證",
    "No certificate imported yet" : "尚未匯入憑證",
    "Import certificate" : "匯入憑證",
    "Import S/MIME certificate" : "匯入 S/MIME 憑證",
    "PKCS #12 Certificate" : "PKCS #12 憑證",
    "PEM Certificate" : "PEM 憑證",
    "Certificate" : "憑證",
    "Private key (optional)" : "私鑰（選擇性）",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "僅當您打算使用此憑證傳送簽署與加密的電子郵件時才需要私鑰。",
    "Back" : "返回",
    "Submit" : "遞交",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "提供的 PKCS #12 憑證必須包含至少一個憑證與一個私鑰。",
    "Failed to import the certificate. Please check the password." : "匯入憑證失敗。請檢查密碼。",
    "Certificate imported successfully" : "成功匯出憑證",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "無法匯入憑證。請確保私鑰與憑證相符，且不受密語保護。",
    "Failed to import the certificate" : "匯入憑證失敗",
    "Keyboard shortcut" : "鍵盤快捷鍵",
    "Keyboard shortcuts" : "鍵盤快捷鍵",
    "Speed up your Mail experience with these quick shortcuts." : "這些鍵盤快捷鍵可加快您的郵件使用體驗。",
    "Compose new message" : "撰寫新信件",
    "Newer message" : "較新的信件",
    "Older message" : "較舊的信件",
    "Toggle star" : "加上／移除星號",
    "Toggle unread" : "標示未讀／已讀",
    "Archive" : "封存",
    "Account connected" : "已連結帳號",
    "You can close this window" : "您可以關閉此視窗",
    "Connect your mail account" : "連結您的郵件帳號",
    "To add a mail account, please contact your administrator." : "要新增郵件帳號，請聯絡您的管理員。",
    "Itinerary for {type} is not supported yet" : "目前尚未支援 {type} 的行程",
    "All" : "全部",
    "Drafts" : "草稿",
    "Favorites" : "我的最愛",
    "Priority inbox" : "優先收件匣",
    "All inboxes" : "所有收件匣",
    "Inbox" : "收件匣",
    "Junk" : "垃圾郵件",
    "Sent" : "寄件備份",
    "Trash" : "回收筒",
    "Connect OAUTH2 account" : "連結 OAUTH2 帳號",
    "Error while sharing file" : "分享檔案時發生錯誤",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n 則新信件\n來自 {from}"],
    "Nextcloud Mail" : "Nextcloud 郵件",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "正在編寫一則訊息。若您繼續，所有未儲存的變更將會遺失！",
    "Discard changes" : "放棄變更",
    "Discard unsaved changes" : "放棄未儲存變更",
    "Keep editing message" : "保留編輯中的訊息",
    "Attachments were not copied. Please add them manually." : "未複製附件。請手動新增它們。",
    "Message sent" : "已傳送郵件",
    "Could not send message" : "無法傳送郵件",
    "Could not load {tag}{name}{endtag}" : "無法載入 {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "載入 {tag}{name}{endtag} 時出現問題",
    "Could not load your message" : "無法載入您的信件",
    "Could not load the desired message" : "無法載入所選的信件",
    "Could not load the message" : "無法載入信件",
    "Error loading message" : "載入信件錯誤",
    "Forwarding to %s" : "正在轉寄給%s",
    "Click here if you are not automatically redirected within the next few seconds." : "如果未在幾秒內重新導向，請點擊此處。",
    "Redirect" : "重新導向",
    "The link leads to %s" : "該連結導向至 %s",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "若不想造訪該頁，您可以回到<a href=\"%s\">郵件</a>。",
    "Continue to %s" : "前往 %s"
},
"nplurals=1; plural=0;");
